@@ -1,29 +1,13 @@
-from .functions import *
 from ..imports import *
-from .info_utils import infoRegistry
-import threading,os,re,yt_dlp,urllib.request,m3u8_To_MP4,subprocess
-from abstract_utilities import get_logFile,safe_dump_to_file
-
-from m3u8 import M3U8  # Install: pip install m3u8
-from urllib.parse import urljoin
-from yt_dlp.postprocessor.ffmpeg import FFmpegFixupPostProcessor
-from abstract_math import divide_it,add_it,multiply_it,subtract_it
-from abstract_pandas import *
-import os, shutil, threading, time, yt_dlp
-from abstract_utilities import safe_dump_to_file
-from .info_utils import infoRegistry, generate_video_id  # from above
-from ..imports import logger  # assuming you have a logger
-
-def get_download_directory(download_directory):
-    d = download_directory or os.path.expanduser("~/Downloads/videos")
-    os.makedirs(d, exist_ok=True)
-    return d
-
-def get_corrected_url(url: str | list):
-    if isinstance(url, list):
-        return url
-    return url.strip()
+from .image_utils import *
 
+def get_corrected_url(url):
+    try:
+        url_mgr = urlManager(url=url)
+        return url_mgr.url
+    except Exception as e:
+        logger.info(f"{e}")
+    return url
 class VideoDownloader:
     def __init__(self, url, download_directory=None, user_agent=None,
                  video_extention="mp4", download_video=True,
@@ -35,14 +19,14 @@ class VideoDownloader:
 
         self.url = get_corrected_url(url=url)
         self.video_urls = self.url if isinstance(self.url, list) else [self.url]
-
+        
         self.registry = registry or infoRegistry()
         self.ydl_opts = ydl_opts or {}
         self.get_download = download_video
         self.get_info = get_info
         self.user_agent = user_agent
         self.video_extention = video_extention
-        self.download_directory = get_download_directory(download_directory)
+        self.download_directory = get_video_root(download_directory)
         self.output_filename = output_filename
         self.force_refresh = force_refresh
         self.info = {}
@@ -155,43 +139,37 @@ class VideoDownloader:
             try:
                 with yt_dlp.YoutubeDL(self._build_ydl_opts(tmp_outtmpl)) as ydl:
                     info = ydl.extract_info(video_url, download=self.get_download)
+
+                    # --- Determine video_id
                     video_id = info.get("id") or generate_video_id(info.get("title") or "video")
-                    dirbase = self.download_directory
-                    if self.download_directory and os.path.isdir(self.download_directory) and not os.path.basename(self.download_directory) == video_id:
-                        # --- Canonical base directory
-                        dirbase = os.path.join(self.download_directory, video_id)
+                    info["video_id"] = video_id
+
+                    # --- Canonical base directory
+                    dirbase = os.path.join(self.download_directory, video_id)
                     os.makedirs(dirbase, exist_ok=True)
-                    
+
                     # --- Final video file
                     temp_path = ydl.prepare_filename(info)
                     _, ext = os.path.splitext(temp_path)
                     final_path = os.path.join(dirbase, f"video{ext or '.mp4'}")
-
                     if temp_path != final_path and os.path.isfile(temp_path):
                         shutil.move(temp_path, final_path)
-
-                    # --- Core info
                     info["file_path"] = final_path
-                    info["video_id"] = video_id
+
+                    # --- Write info.json
                     info_path = os.path.join(dirbase, "info.json")
                     safe_dump_to_file(info, info_path)
                     info["info_path"] = info_path
 
-                    # --- Add placeholders for extras
-                    info.update({
-                        "audio_path": os.path.join(dirbase, "audio.wav"),
-                        "whisper_path": os.path.join(dirbase, "whisper.json"),
-                        "srt_path": os.path.join(dirbase, "captions.srt"),
-                        "metadata_path": os.path.join(dirbase, "metadata.json"),
-                        "thumbnails_dir": os.path.join(dirbase, "thumbnails"),
-                    })
-                    os.makedirs(info["thumbnails_dir"], exist_ok=True)
+                    # --- Normalize with schema (critical!)
+                    info = ensure_standard_paths(info, self.download_directory)
 
                     # --- Update registry
                     self.registry.edit_info(
-                        data={"file_path": final_path, "info_path": info_path, **info},
+                        data=info,
                         url=video_url,
-                        video_id=video_id
+                        video_id=video_id,
+                        video_path=final_path
                     )
 
                     logger.info(f"[VideoDownloader] Downloaded and stored at {final_path}")
@@ -200,4 +178,3 @@ class VideoDownloader:
             except Exception as e:
                 logger.error(f"[VideoDownloader] Download failed: {e}")
                 return None
-
